from django import forms
from django.core.exceptions import ValidationError
from .models import UserProfile,Cuisine,Context
from registration.forms import RegistrationForm

class UserProfileForm(forms.ModelForm):
	class Meta:
		model = UserProfile
		fields = ('birthyear', 'sex', 'nationality')

class FilterForm(forms.Form):
	cuisine = forms.ModelChoiceField(queryset=Cuisine.objects.all(),required=False)
	price_choices = [(None,"--------"),(1,"$15"),(2,"$15-30"),(3,"$30-50"),(4,"$50-75"),(5,"$75")]
	price = forms.ChoiceField(choices=price_choices,required=False)

	rating_choices = [(0.0,"-"),(1.0,1.0),(1.5,1.5),(2.0,2.0),(2.5,2.5),(3.0,3.0),(3.5,3.5),
					  (4.0,4.0),(4.5,4.5),(5.0,5.0)]

	min_rating = forms.ChoiceField(choices=rating_choices, required=False, label="Minimum rating")
	max_rating = forms.ChoiceField(choices=rating_choices, required=False, label="Maximum rating")

	def clean(self):
		min_rating = float(self.cleaned_data.get('min_rating'))
		max_rating = float(self.cleaned_data.get('max_rating'))
		if ((min_rating > max_rating) and (min_rating != 0.0) and (max_rating != 0.0)):
			raise ValidationError("Minimum rating can not be larger than maximum rating!")

class UserRegistrationForm(RegistrationForm):
    def __init__(self, *args, **kwargs):
        super(RegistrationForm, self).__init__(*args, **kwargs)
        self.fields.pop('email')

class RecommendForm(forms.Form):
    context = forms.ModelChoiceField(queryset=Context.objects.all(), label="")


