from django.core.management.base import BaseCommand
from recapp.models import UserRating
from django.contrib.auth.models import User
from scikits.crab.models import MatrixPreferenceDataModel
from scikits.crab.metrics import pearson_correlation
from scikits.crab.similarities import UserSimilarity
from scikits.crab.recommenders.knn import UserBasedRecommender

class Command(BaseCommand):
    help = 'populate database'

    def handle(self, *args, **options):
        liste = self.cf_rec(2,1)
        self.stdout.write(str(liste))

    def cf_rec(self, user_id,context_id):
        ratings = self.build_dict(context_id)
        self.stdout.write(str(ratings))
        model = MatrixPreferenceDataModel(ratings)

        similarity = UserSimilarity(model, pearson_correlation)
        recommender = UserBasedRecommender(model, similarity, with_preference=True)

        return recommender.recommend(user_id)

    def build_dict(self, context_id):
        dict = {}
        for user in User.objects.all():
            ratings = UserRating.objects.filter(user_id=user.id,context_id=context_id)
            ratingDict = {}

            for rating in ratings:
                ratingDict[rating.restaurant] = rating.value

            dict[user.id] = ratingDict
        return dict